countries.Place (Place) — amici1

# `countries.Place` (Place)

Place(id, parent, name, country, zip_code, type, show_type, name_de, name_fr)

Master tables : countries.Places (Places)

Slave tables : addresses.AddressesByCity (Addresses), contacts.PartnersByCity (Partners), countries.PlacesByPlace (Subdivisions)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Part of (parent) : The superordinate geographic place of which this place is a part.

- Designation (name) : See `<lino.utils.mldbc.fields.BabelCharField: name>`.

- Country (country) : The country this place is in.

- zip code (zip_code) : See `<django.db.models.fields.CharField: zip_code>`.

- Place Type (type) : The type of this place (whether it’s a city. a village, a province…)

- Show type (show_type) : See `<django.db.models.fields.BooleanField: show_type>`.

- Designation (de) (name_de) : See `<django.db.models.fields.CharField: name_de>`.

- Designation (fr) (name_fr) : See `<django.db.models.fields.CharField: name_fr>`.

- Children (children_summary) : A comma-separated list of the children.

- (None) (treeview_panel) : See `lino_xl.lib.countries.models.Place.treeview_panel`.

- Name (name_column) : See `lino_xl.lib.countries.models.Place.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.countries.models.Place.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.countries.models.Place.overview`.

Referenced from addresses.Address.city, addresses.Address.region, contacts.Partner.city, contacts.Partner.region, countries.Place.parent

## Database fields

Internal name | Verbose name | Help text
id | ID |
parent | Part of | The superordinate geographic place of which this place is a part.
name | Designation |
country | Country | The country this place is in.
zip_code | zip code |
type | Place Type | The type of this place (whether it’s a city. a village, a province…)
show_type | Show type |
name_de | Designation (de) |
name_fr | Designation (fr) |
children_summary | Children | A comma-separated list of the children.
treeview_panel | None |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |